.. currentmodule:: sardana.macroserver.msmanager

:mod:`~sardana.macroserver.msmanager`
=======================================

.. automodule:: sardana.macroserver.msmanager

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MacroServerManager`

MacroServerManager
------------------

.. inheritance-diagram:: MacroServerManager
    :parts: 1
    
.. autoclass:: MacroServerManager
    :show-inheritance:
